@@ -16,7 +16,8 @@ var classFl__Text__Display =
     [ "cursor_color", "classFl__Text__Display.html#a17bfc3af03f82c18c7ebb6ef34ed2139", null ],
     [ "cursor_style", "classFl__Text__Display.html#a6f4751931de885d4907e659d97acab30", null ],
     [ "display_insert", "classFl__Text__Display.html#ac5de2af1a6744d3f7be1fc7c53343f75", null ],
-    [ "draw", "classFl__Text__Display.html#aed2bc401bcb2effc9cf175499f960637", null ],
+    [ "display_needs_recalc", "classFl__Text__Display.html#ae866a3c3130570ef61c632b7a0e2c43a", null ],
+    [ "draw", "classFl__Text__Display.html#a2db0c8c740c19c6903a860fa3ceb9a4f", null ],
     [ "draw_cursor", "classFl__Text__Display.html#a5e5d522b89d167554ad059bc9a39b9b4", null ],
     [ "draw_line_numbers", "classFl__Text__Display.html#afc77f4bedb15408180b704a91252af80", null ],
     [ "draw_range", "classFl__Text__Display.html#a63df8b065f442f04eb0653318e048612", null ],
@@ -29,7 +30,10 @@ var classFl__Text__Display =
     [ "find_wrap_range", "classFl__Text__Display.html#a825d640ec72904f7fe27cae8881a0e5a", null ],
     [ "find_x", "classFl__Text__Display.html#a74d290bbc81bab4c98ca537955f3a82f", null ],
     [ "get_absolute_top_line_number", "classFl__Text__Display.html#a9496ca6e33b127a2f66ea1b2a1202151", null ],
-    [ "handle", "classFl__Text__Display.html#a48649283f44cb7eacfbdc1e58bb9a73d", null ],
+    [ "grammar_underline_color", "classFl__Text__Display.html#a91e871bc1f1ba50fb19b3841bbf96058", null ],
+    [ "grammar_underline_color", "classFl__Text__Display.html#ad96059453dbf1035e7e4f8ffed5c60ae", null ],
+    [ "handle", "classFl__Text__Display.html#a97c837f06cfbaed3e7cdfc2e43f1089d", null ],
+    [ "handle_rmb", "classFl__Text__Display.html#a7c9c4fb06430deb98091249362c1efbd", null ],
     [ "handle_vline", "classFl__Text__Display.html#a10713a9bb22e486887eeda7f75324389", null ],
     [ "hide_cursor", "classFl__Text__Display.html#a04ba6677e453106781e28f4fc75dcef8", null ],
     [ "highlight_data", "classFl__Text__Display.html#ae09d61739b737a32868ffe0295a25dec", null ],
@@ -71,22 +75,30 @@ var classFl__Text__Display =
     [ "position_to_linecol", "classFl__Text__Display.html#a772ace0180ebf38f2dc7b6402fd62501", null ],
     [ "position_to_xy", "classFl__Text__Display.html#a0bf0bfb6bb3ac9d6b4774b8a2b1849ec", null ],
     [ "previous_word", "classFl__Text__Display.html#a83c23e74c58e01e61259a6bbaf632ed3", null ],
+    [ "recalc_display", "classFl__Text__Display.html#a2c2089df8e61ec00991abda79026f1fe", null ],
     [ "redisplay_range", "classFl__Text__Display.html#a6ec6a8ca047a45805522efbc301c786a", null ],
     [ "reset_absolute_top_line_number", "classFl__Text__Display.html#a29cca6a03ac20b1af20913c5a0e25fe7", null ],
-    [ "resize", "classFl__Text__Display.html#af7f084870d9d94439520886008fcdddd", null ],
+    [ "resize", "classFl__Text__Display.html#ad0fb241ff581cc363271b6f960ec60c8", null ],
     [ "rewind_lines", "classFl__Text__Display.html#ab979d92ae92c3209cabd187028d61029", null ],
     [ "scroll", "classFl__Text__Display.html#aa6705c216c0626763f3f34d3e318d465", null ],
     [ "scroll_", "classFl__Text__Display.html#ac59b0199f494e20eae3fb270bd20b0f9", null ],
     [ "scrollbar_align", "classFl__Text__Display.html#a26f6e0b2a781f023d5a13b9bdd0af486", null ],
     [ "scrollbar_align", "classFl__Text__Display.html#a4b14388f53b951244edcfab51c2a1e18", null ],
+    [ "scrollbar_size", "classFl__Text__Display.html#a6dc75e23d3fc181683118072436ba537", null ],
+    [ "scrollbar_size", "classFl__Text__Display.html#a21bf730e770cf58a28cacdd2282d981b", null ],
     [ "scrollbar_width", "classFl__Text__Display.html#a0006a273fa0a2370e6db2d6aa079fcb6", null ],
-    [ "scrollbar_width", "classFl__Text__Display.html#a3947903141cbc6f4b125e9aef5f5d388", null ],
+    [ "scrollbar_width", "classFl__Text__Display.html#a461a7dc773676851db6031519fee1d7e", null ],
+    [ "secondary_selection_color", "classFl__Text__Display.html#aa2c0ac920985d75fb269a7b93b8c6624", null ],
+    [ "secondary_selection_color", "classFl__Text__Display.html#af26ffb470359b2301c6c385611969a6a", null ],
     [ "shortcut", "classFl__Text__Display.html#a98f01dd6b8be0522e54bccf0f3587d47", null ],
     [ "shortcut", "classFl__Text__Display.html#a3ec453b6dc9cc468619688c5bdf3dc95", null ],
     [ "show_cursor", "classFl__Text__Display.html#a2e19af56aacc79cbefe426ca6255099d", null ],
     [ "show_insert_position", "classFl__Text__Display.html#aadc28a301981f02edc3d57913f56b766", null ],
     [ "skip_lines", "classFl__Text__Display.html#adf4a0d3ffb4ebdd34954d1781516653c", null ],
+    [ "spelling_underline_color", "classFl__Text__Display.html#aa3ea085c94d050410def6111a4551eb7", null ],
+    [ "spelling_underline_color", "classFl__Text__Display.html#ae16f7a633f5500b2abc0237bad353871", null ],
     [ "string_width", "classFl__Text__Display.html#a033fb1323b0640601240829e845598f9", null ],
+    [ "style_buffer", "classFl__Text__Display.html#acce0f152b6c18f0f4cf1d3d0e43a1a58", null ],
     [ "textcolor", "classFl__Text__Display.html#a8695a84858aa91aef4323f4618cab9b7", null ],
     [ "textcolor", "classFl__Text__Display.html#a2572e2a4e5bccd59fb94e46b1329e4cf", null ],
     [ "textfont", "classFl__Text__Display.html#aede1822b26480e2d08c3625b67f7abe3", null ],
